import { useMarkStore } from "@/store";
import { getStatus } from "@/api/markPage";
import { watch } from "vue";

export default function useStatus() {
  const markStore = useMarkStore();

  async function updateStatus() {
    const res = await getStatus(markStore.setting.questionModel);
    markStore.setInfo({ status: res.data });

    // 单题阅的模式status可能有多条，需要依据评卷的试题来确定显示哪一条
    // 整卷阅的模式下只有一条，所以只取第一条数据
    if (!markStore.isSingelQuestionModel) {
      markStore.setInfo({ curStatus: res.data[0] });
    }
  }

  // 单题阅的模式下才需要监听当前题目状态
  function listenStatusQuestion() {
    watch(
      () => markStore.currentQuestion,
      (val) => {
        if (!val) return;
        const { mainNumber, subNumber } = val;
        markStore.setInfo({
          curStatus: markStore.status.find(
            (item) =>
              item.mainNumber === mainNumber && item.subNumber === subNumber
          ),
        });
      }
    );
  }

  return {
    updateStatus,
    listenStatusQuestion,
  };
}
